[](http://www.network-science.de/ascii/)
<pre>
 **    **     **        *******
//**  **     ****      /**////**
 //****     **//**     /**   /**
  //**     **  //**    /*******
   /**    **********   /**////
   /**   /**//////**   /**
   /**   /**     /**   /**
   //    //      //    //
</pre>

# YAP (Yet Another Pipeline)
Pipeline(s) for mapping and cluster-level aggregation of single nucleus methylome and multi-omic datasets.
Technologies supported:
- snmC-seq(1/2/3)
- snmCT-seq (mC + RNA)
- snmC2T-seq (mC + RNA + Chromatin Accessibility)
- snm3C-seq (mC + Chromatin Conformation)
- any NOMe treated version of the above

[See Documentation](https://hq-1.gitbook.io/mc/)
